==> gnaural_0.3.20060421.orig.tar.gz: gnaural-0.3.20060421/src/callbacks.h <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>


gboolean
on_window1_delete_event                (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_save1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_open1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_edit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_reload1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_restore_default_settings_and_file1_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_create_wav_audio_file1_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_create_mp3_audio_file1_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);


void
on_quit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_set_base_frequency1_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_set_beat_frequency1_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_stereo_noise1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_infinite_loop_mode1_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_disable_screensaver1_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_gnaural_help1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about_gnaural1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_buttonPlay_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonRewind_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonRewind_pressed                (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonForward_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonForward_pressed               (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonStop_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_vscale_VolumeTone_value_changed     (GtkRange        *range,
                                        gpointer         user_data);

void
on_vscale_VolumeNoise_value_changed    (GtkRange        *range,
                                        gpointer         user_data);

void
on_hscale_FreqBeat_value_changed       (GtkRange        *range,
                                        gpointer         user_data);

void
on_checkbutton_FreqBeat_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_hscale_FreqBase_value_changed       (GtkRange        *range,
                                        gpointer         user_data);

void
on_checkbutton_FreqBase_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_drawingarea1_expose_event           (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_configure_event        (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_delete_event           (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_motion_notify_event    (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_button_release_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_graph1_apply1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_clear1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_roundvalues_hundreth1_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_roundvalues_tenth1_activate  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_roundvalues_digit1_activate  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_save_as1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_reload2_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_undo1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_redo1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_window1_destroy_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_window1_destroy                     (GtkObject       *object,
                                        gpointer         user_data);

void
on_drawingarea1_destroy                (GtkObject       *object,
                                        gpointer         user_data);

void
on_graph_threshset_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_drawingarea1_key_press_event        (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

gboolean
on_window1_key_press_event             (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_graph_copy1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_cut1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_paste1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_delete1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_deselect1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_roundoff_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_set_hz1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_scale1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_add_noise1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_select_previous_points1_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_select_next_points1_activate (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_set1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_select1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_cut_time1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_delete_time1_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_window1_key_release_event           (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_graph_invert_selection1_activate    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_select_interval1_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_delete_duplicates1_activate   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

==> gnaural_0.4.20070301.orig.tar.gz: gnaural-0.4.20070301/src/callbacks.h <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>


gboolean
on_window1_delete_event                (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_save1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_open1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_edit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_reload1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_restore_default_settings_and_file1_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_create_wav_audio_file1_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_create_mp3_audio_file1_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);


void
on_quit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_set_base_frequency1_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_set_beat_frequency1_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_stereo_noise1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_infinite_loop_mode1_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_disable_screensaver1_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_gnaural_help1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about_gnaural1_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_buttonPlay_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonRewind_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonRewind_pressed                (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonForward_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonForward_pressed               (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonStop_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_vscale_VolumeTone_value_changed     (GtkRange        *range,
                                        gpointer         user_data);

void
on_vscale_VolumeNoise_value_changed    (GtkRange        *range,
                                        gpointer         user_data);

void
on_hscale_FreqBeat_value_changed       (GtkRange        *range,
                                        gpointer         user_data);

void
on_checkbutton_FreqBeat_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_hscale_FreqBase_value_changed       (GtkRange        *range,
                                        gpointer         user_data);

void
on_checkbutton_FreqBase_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_drawingarea1_expose_event           (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_configure_event        (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_delete_event           (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_motion_notify_event    (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_button_release_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_graph1_apply1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_clear1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_roundvalues_hundreth1_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_roundvalues_tenth1_activate  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_roundvalues_digit1_activate  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_save_as1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_reload2_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_undo1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_redo1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_window1_destroy_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_window1_destroy                     (GtkObject       *object,
                                        gpointer         user_data);

void
on_drawingarea1_destroy                (GtkObject       *object,
                                        gpointer         user_data);

void
on_graph_threshset_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_drawingarea1_key_press_event        (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

gboolean
on_window1_key_press_event             (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_graph_copy1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_cut1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_paste1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_delete1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_deselect1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_roundoff_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_set_hz1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_scale1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_add_noise1_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_select_previous_points1_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph1_select_next_points1_activate (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_set1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_select1_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_cut_time1_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_delete_time1_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_window1_key_release_event           (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_graph_invert_selection1_activate    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_select_interval1_activate     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_graph_delete_duplicates1_activate   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_hscale_Volume_value_changed         (GtkRange        *range,
                                        gpointer         user_data);

void
on_hscale_Balance_value_changed        (GtkRange        *range,
                                        gpointer         user_data);

void
on_checkbutton_StereoSwap_toggled      (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_buttonApplyClicked_clicked          (GtkButton       *button,
                                        gpointer         user_data);
